@@ -5,10 +5,10 @@ use serde_json::Value;
  * @Author: tzw
  * @Date: 2021-11-16 21:16:13
  * @LastEditors: tzw
- * @LastEditTime: 2021-11-16 23:52:16
+ * @LastEditTime: 2021-12-19 20:46:41
  */
 
-#[derive(Debug, Serialize, Deserialize, Clone)]
+#[derive(Debug, Serialize, Deserialize, Clone,Default)]
 pub struct CloudEvent {
    pub id: Option<String>,
    pub traceid: Option<String>,
