@@ -2,13 +2,13 @@
  * @Author: tzw
  * @Date: 2021-11-09 02:01:16
  * @LastEditors: tzw
- * @LastEditTime: 2021-11-22 00:48:31
+ * @LastEditTime: 2021-12-16 00:40:49
  */
 use tonic::*;
 
 use dapr::{
     appcallback::*,
-    dapr::dapr::proto::runtime::v1::app_callback_server::{AppCallback, AppCallbackServer},
+    dapr::dapr::proto::runtime::v1::app_callback_server::{AppCallback},
 };
 
 #[derive(Default)]
