@@ -2,7 +2,7 @@
  * @Author: tzw
  * @Date: 2021-10-31 23:26:50
  * @LastEditors: tzw
- * @LastEditTime: 2021-11-29 20:12:42
+ * @LastEditTime: 2021-12-19 20:45:45
  */
 use std::collections::HashMap;
 use serde::{Deserialize, Serialize};
@@ -14,7 +14,7 @@ eventuate 消息定义
 pub trait Imessage{
 
 }
-#[derive(Serialize, Deserialize,Clone,Debug)]
+#[derive(Serialize, Deserialize,Clone,Debug,Default)]
 pub struct Headers{
    pub ID: Option<String>,
    pub PARTITION_ID:Option<String>,
@@ -30,7 +30,7 @@ pub struct Headers{
     pub extra: HashMap<String, Value>,
 }
 
-#[derive(Serialize, Deserialize,Clone, Debug)]
+#[derive(Serialize, Deserialize,Clone, Debug,Default)]
 pub struct MessageImpl{
     pub payload: Option<String>,
     pub headers: Option<Headers>,
