@@ -2,7 +2,7 @@
  * @Author: tzw
  * @Date: 2021-11-03 20:40:06
  * @LastEditors: tzw
- * @LastEditTime: 2021-11-22 01:04:52
+ * @LastEditTime: 2021-11-29 22:25:03
  */
 #[cfg(test)]
  pub mod tests {
@@ -26,7 +26,7 @@
     }
     #[actix_rt::test]
     pub async fn http_reqwest(){
-        let body = reqwest::get("http://122.9.125.181/auth/realms/tdcare/protocol/openid-connect/certs").await?;
+        let body = reqwest::get("http://122.9.125.181/auth/realms/tdcare/protocol/openid-connect/certs").await.unwrap();
 
         println!("Response: {:?}", body);
     }
